@@ -308,6 +308,8 @@ def run_s2p(ops={},db={}):
 
             # save as matlab file
             if 'save_mat' in ops and ops['save_mat']:
+                if 'date_proc' in ops:
+                    ops['date_proc'] = []
                 stat = np.load(os.path.join(fpath,'stat.npy'), allow_pickle=True)
                 iscell = np.load(os.path.join(fpath,'iscell.npy'))
                 matpath = os.path.join(ops['save_path'],'Fall.mat')
